<?php
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 *
 */
class Routee_Functions{

	/**
	 * AUTH_MODE
	 */
	const AUTH_MODE  = 'auth';

	/**
	 * DATA_MODE
	 */
	const DATA_MODE  = 'data';

	/**
	 * EVENT_MODE
	 */
	const EVENT_MODE = 'event';

	/**
	 * EVENT_MODE2
	 */
	const EVENT_MODE2 = 'event2';

	/**
	 * @var integer
	 */
    private $limit = 100;

	/**
	 * @return void
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'Routee_Menu' ) );

		add_action( 'wp_ajax_routee_login', array( $this, 'Routee_login' ) );
		add_action( 'wp_ajax_routee_mass_data', array( $this, 'Routee_MassData' ) );

		add_action( 'user_register', array( $this, 'Routee_NewUserRegister' ) );

		add_action( 'woocommerce_update_customer', array( $this, 'Routee_UserUpdate' ) , 10, 3 );

		add_action( 'transition_post_status', array( $this, 'Routee_ProductHook' ), 10, 3 );
		add_action( 'transition_post_status', array( $this, 'Routee_ArticleHook' ), 20, 3 );

		add_action( 'woocommerce_no_stock', array( $this, 'Routee_woocommerce_no_stock' ), 10, 1 );
		add_action( 'woocommerce_updated_product_stock', array( $this, 'Routee_woocommerce_updated_product_stock' ), 10, 1 );

		add_action( 'woocommerce_add_to_cart', array( $this, 'Routee_woocommerce_add_to_cart' ), 10, 3 );
		add_action( 'woocommerce_after_cart_item_quantity_update', array( $this, 'Routee_woocommerce_add_to_cart' ), 20, 4 );
		add_action( 'woocommerce_remove_cart_item', array( $this, 'Routee_remove_cart_items' ), 10, 2 );

		add_action( 'woocommerce_checkout_order_processed', array( $this, 'Routee_woocommerce_checkout_order' ), 10, 1 );
		add_action( 'woocommerce_order_status_changed', array( $this, 'Routee_order_update_callback' ), 10, 1 );
		add_action( 'woocommerce_order_status_completed', array( $this, 'Routee_woocommerce_order_status_completed' ), 10, 3 );

        add_action('wp_ajax_routee_log_export_csv', array($this, 'routee_log_export_csv'));
        add_action('wp_ajax_nopriv_routee_log_export_csv', array($this, 'routee_log_export_csv'));

        add_action('wp_ajax_routee_log_api', array($this, 'routee_log_api'));
        add_action('wp_ajax_nopriv_routee_log_api', array($this, 'routee_log_api'));

        add_action('admin_init', array($this, 'routee_remove_log'));
	}

	/**
	 * @return void
	 */
	public function Routee_Menu(){
		add_menu_page(
			__('Routee_Menu'),
			'Routee',
			'edit_pages',
			'Routee_Menu',
			array( $this, 'Routee_login_screen' )
		);
	}

	/**
	 * @return void
	 */
	public function Routee_login_screen(){
        $RouteeAuthorized = get_option( 'RouteeAuthorized' );
		if($RouteeAuthorized == '1'){
			include 'thank.php';
		}else{
			include 'login.php';
		}
	}

	/**
	 * @return void
	 */
	public function Routee_login() {
        RouteeEventExecutedLog('Routee_login', 'auth');
        $nonce = $_POST['_ajax_nonce'];

		if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) )
			die ( 'Busted!');

		ob_clean();
		parse_str($_POST['form_data'],$data);

		$source = in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ? "WooCommerce" : "Wordpress";
		global $wp_version;
		$login_data = array(
			'username' => $data['routee_user'],
			'password' => $data['routee_password'],
			'source' => $source,
			'type' => 'E-COMMERCE',
			'version' => $wp_version,
			'plugin_version' => ROUTEE_PLUGIN_VERSION,
			'domain' => get_site_url()
		);

        RouteeEventGrabData('Routee_login', $login_data, 'auth');

		$result = Routee_http_call( self::AUTH_MODE, $login_data );

		if( $result['success']  && isset( $result['data']['uuid'] ) ){

			$uuid = $result['data']['uuid'];
			/* Save option in Wp */
			update_option( 'RouteeLoginUser', trim($data['routee_user']));
			update_option( 'RouteeLoginPswd', trim($data['routee_password']));
			update_option( 'RouteeLoginCode', trim($uuid));
			update_option( 'RouteeAuthorized', trim('1'));

			$flag = true;
			$msg = 'You are successfully authorized';
		}else{
			$flag = false;
			$msg = isset( $result['data']['message'] ) ? $result['data']['message'] : "Some error occured, Please try again";
		}

		$resp = array(
			'flag' => $flag,
			'msg' => $msg,
		);
		wp_send_json($resp);
	}

	/**
	 * @return void
	 */
	public function Routee_MassData() {
		$nonce = $_POST['_ajax_nonce'];

		if ( ! wp_verify_nonce( $nonce, 'ajax-nonce' ) )
			die ( 'Busted!');

		$data_type = $_POST['data_type'];
		$data_cycle = $_POST['data_cycle'];
		$resp = [];
		$uuid = get_option( 'RouteeLoginCode' );
		switch ($data_type){
			case "product":
				$resp = $this->Routee_HandleProductMassExport($uuid, $data_cycle);
			break;

			case "customer":
				$resp = $this->Routee_HandleCustomerMassExport($uuid, $data_cycle);
			break;

			case "order":
				$resp = $this->Routee_HandleOrderMassExport($uuid, $data_cycle);
			break;
		}
		wp_send_json($resp);
	}

	/**
	 * @return void
	 */
	private function Routee_HandleProductMassExport( $uuid, $data_cycle ) {
        RouteeEventExecutedLog('ProductMassExport', 'mass data');

        global $wpdb;
        $return["reload"] = 0;
        $offset = $this->limit * $data_cycle;
        $querystr = "
			    SELECT $wpdb->posts.ID
			    FROM $wpdb->posts
			    WHERE $wpdb->posts.post_status = 'publish' 
			    AND $wpdb->posts.post_type = 'product'
			    ORDER BY $wpdb->posts.ID ASC
				LIMIT ". $this->limit ." OFFSET " . $offset;

        $pageposts = $wpdb->get_results($querystr, OBJECT);
        $count = count($pageposts);
        if ( $count > 0 ) {


            $mass_data_product = array(
                'uuid' => $uuid,
                'data' => array(
                    array(
                        'name' => 'Products',
                        'description' => 'Shop Products'
                    )
                )
            );

            foreach ($pageposts as $key => $post) {
                $WC_Product = wc_get_product( $post->ID);
                $mass_data_product['data'][0]['object'][$key] =  RouteeProductArray($WC_Product);
            }

            RouteeEventGrabData('ProductMassExport', $mass_data_product, 'mass data');

            $result = Routee_http_call( self::DATA_MODE, $mass_data_product );
            if ( $result['success'] == 1 && $count < $this->limit ){
                update_option("RouteeProductSynced", 1);
                $return["reload"] = 1;
            }
        } else {
            update_option("RouteeProductSynced", 1);
            $return["reload"] = 1;
        }
        return $return;
	}

	/**
	 * @return void
	 */
	private function Routee_HandleCustomerMassExport( $uuid, $data_cycle ) {
        RouteeEventExecutedLog('CustomerMassExport', 'mass data');

        $return["reload"] = 0;
        $customer_query = new WP_User_Query(
            array(
                'fields' => 'ID',
                'role' => 'customer',
                'orderby' => 'ID',
                'number' => $this->limit,
                'paged' => $data_cycle + 1
            )
        );

        $cust_res = $customer_query->get_results();

        $count = count($cust_res);

        if ( $count > 0 ) {
            $mass_data_customer = array(
                'uuid' => $uuid,
                'data' => array(
                    array(
                        'name' => 'Customers',
                        'description' => 'Shop Customers'
                    )
                )
            );

            foreach ($cust_res as $ind => $custID) {
                $mass_data_customer['data'][0]['object'][$ind] = RouteeUserArray( $custID );
            }

            RouteeEventGrabData('CustomerMassExport', $mass_data_customer, 'mass data');

            $result = Routee_http_call( self::DATA_MODE, $mass_data_customer );
            if ( $result['success'] == 1 && $count < $this->limit ){
                update_option("RouteeCustomerSynced", 1);
                $return["reload"] = 1;
            }
        } else {
            update_option("RouteeCustomerSynced", 1);
            $return["reload"] = 1;
        }
        return $return;
	}

	/**
	 * @return void
	 */
	private function Routee_HandleOrderMassExport( $uuid, $data_cycle ) {
        RouteeEventExecutedLog('OrderMassExport', 'mass data');

        global $wpdb;
        $return["reload"] = 0;
        $offset = $this->limit * $data_cycle;
        $orderstr = "
			    SELECT $wpdb->posts.ID
			    FROM $wpdb->posts
			    WHERE $wpdb->posts.post_type = 'shop_order'
			    ORDER BY $wpdb->posts.ID ASC
				LIMIT ". $this->limit ." OFFSET " . $offset;

        $order_res = $wpdb->get_results($orderstr, OBJECT);
        $count = count($order_res);
        if ( $count > 0 ) {
            $mass_data_order = array(
                'uuid' => $uuid,
                'data' => array(
                    array(
                        'name'        => 'Orders',
                        'description' => 'Shop Orders'
                    )
                )
            );

            foreach ( $order_res as $ind => $order ) {
                $order_id                                   = $order->ID;
                $mass_data_order['data'][0]['object'][ $ind ] = RouteeOrderDetails( $order_id );
                $order                                      = wc_get_order( $order_id );
                $order_items                                = $order->get_items();

                foreach ( $order_items as $product ) {
                    $mass_data_order['data'][0]['object'][ $ind ]['order_products'][] = array(
                        'product_id'   => $product['product_id'],
                        'variation_id' => $product['variation_id'],
                        'quantity'     => $product['qty']
                    );
                }
            }

            RouteeEventGrabData('OrderMassExport', $mass_data_order, 'mass data');

            $result = Routee_http_call( self::DATA_MODE, $mass_data_order );
            if ( $result['success'] == 1 && $count < $this->limit ){
                update_option("RouteeOrderSynced", 1);
                $return["reload"] = 1;
            }
        } else {
            update_option("RouteeOrderSynced", 1);
            $return["reload"] = 1;
        }
        return $return;
	}

	/**
	 * @param $user_id
	 *
	 * @return void
	 */
	public function Routee_NewUserRegister( $user_id ) {
        RouteeEventExecutedLog('CustomerAdd', 'events');

		$post_data = RouteeUserArray($user_id);
        RouteeEventGrabData('CustomerAdd', $post_data, 'events');

		Routee_http_call( self::EVENT_MODE, $post_data,'CustomerAdd', $user_id);
	}

	/**
	 * @param $user_id
	 *
	 * @return void
	 */
	public function Routee_UserUpdate( $user_id ){
        RouteeEventExecutedLog('CustomerUpdate', 'events');

		$post_data = RouteeUserArray($user_id);
        RouteeEventGrabData('CustomerUpdate', $post_data, 'events');

		Routee_http_call( self::EVENT_MODE, $post_data,'CustomerUpdate', $user_id );
	}

	/**
	 * @param $new_status
	 * @param $old_status
	 * @param $post
	 *
	 * @return void
	 */
	public function Routee_ProductHook( $new_status, $old_status, $post ){
		if ( $post->post_type != 'product' ) {
			return;
		}
		$product_id = $post->ID;

		switch(true) {

			case ( $old_status == 'auto-draft' && $new_status == 'publish' ) :
			case ( $old_status == 'draft' && $new_status == 'publish' ) :
			case ( $old_status == 'trash' && $new_status == 'publish' ) :
				$this->Routee_new_product( $product_id );
			break;

			case ( $old_status == 'publish' && $new_status == 'publish' ) :
				$this->Routee_update_product( $product_id );
			break;

			case ( $old_status == 'publish' && $new_status == 'trash' ) :
				$this->Routee_trash_product( $product_id );
			break;

		}
	}

	/**
	 * @param $product_id
	 *
	 * @return void
	 */
	public function Routee_new_product( $product_id ) {
        RouteeEventExecutedLog('ProductAdd', 'events');

		$product = wc_get_product( $product_id );
		$post_data = RouteeProductArray( $product );
        RouteeEventGrabData('ProductAdd', $post_data, 'events');

		Routee_http_call( self::EVENT_MODE, $post_data, 'ProductAdd', $product_id );

	}

	/**
	 * @param $product_id
	 *
	 * @return void
	 */
	public function Routee_update_product( $product_id ) {
        RouteeEventExecutedLog('ProductUpdate', 'events');

        $product = wc_get_product( $product_id );
		$post_data = RouteeProductArray( $product );
        RouteeEventGrabData('ProductUpdate', $post_data, 'events');

		Routee_http_call( self::EVENT_MODE, $post_data, 'ProductUpdate', $product_id );
	}

	/**
	 * @param $product_id
	 *
	 * @return void
	 */
	public function Routee_trash_product( $product_id ) {
        RouteeEventExecutedLog('ProductDelete', 'events');

		$data['product_id'] = $product_id;
        RouteeEventGrabData('ProductDelete', $data, 'events');

		Routee_http_call( self::EVENT_MODE, $data, 'ProductDelete', $product_id );
	}

	/**
	 * @param $new_status
	 * @param $old_status
	 * @param $post
	 *
	 * @return void
	 */
	public function Routee_ArticleHook( $new_status, $old_status, $post ){

		if ( $post->post_type != 'post' ) {
			return;
		}
		switch(true) {

			case ( $old_status == 'auto-draft' && $new_status == 'publish' ) :
			case ( $old_status == 'draft' && $new_status == 'publish' ) :
			case ( $old_status == 'trash' && $new_status == 'publish' ) :
				$this->Routee_article_published( $post );
				break;
		}
	}

	/**
	 * @param WP_Post $post
	 *
	 * @return void
	 */
	private function Routee_article_published( $post ) {
        RouteeEventExecutedLog('article_published', 'events');

		$tag_titles = $urls = [];
		$tags = get_the_tags($post);
		if (!empty($tags)) {
			foreach ( $tags as $tag ) {
				$tag_titles[] = $tag->name;
			}
		}
		$cat_titles = $this->Routee_GetPostCategories($post->ID);
		$attachments = get_posts( array(
			'post_type' => 'attachment',
			'posts_per_page' => -1,
			'post_parent' => $post->ID,
			'exclude'     => get_post_thumbnail_id()
		) );
		if (!empty($attachments)) {
			foreach ( $attachments as $attachment ) {
				$urls[] = $attachment->guid;
			}
		}
		$latest_posts = $this->Routee_GetLatestPostsData();

		$post_data = array(
			"name" => "article_published",
			"display_name" => "article_published",
			"description" => "When an article is created",
			"natural_language" => "... created an article",
			"type" => "active",
			"source" => "WooCommerce Plugin",
			"timestamp" => time(),
			"customerID" => get_current_user_id(),
			"visitorID" => get_current_user_id(),
			"data" => array(
				  "article_title" => $post->post_title,
				  "article_content" => RouteeLimitText($post->post_content, 1000),
			      "article_id" => $post->ID,
			      "article_tags" => implode( ",", $tag_titles),
			      "article_categories" => implode( ",", $cat_titles),
			      "published_at" => $post->post_date,
			      "blog_author" => $post->post_author,
			      "article_URL" => get_permalink($post),
			      "excerpt" => $post->post_excerpt,
			      "images" => array(
				      "url" => $urls
			      ),
				  "latest_posts" => $latest_posts,
			),
		);

        RouteeEventGrabData('article_published', $post_data, 'events');

		Routee_http_call( self::EVENT_MODE, $post_data, 'article_published', $post->ID );
		Routee_http_call( self::EVENT_MODE2, $post_data, 'article_published', $post->ID );
	}

    /**
     * @return array
     */
	private function Routee_GetLatestPostsData() {
		$data = array();
		$latest_posts = RouteeGetLatestPosts();
		if ( count($latest_posts) > 0 ) {
			foreach ( $latest_posts as $latest_post ) {
				$post = get_post($latest_post->ID);
				$data[] = array(
					"article_id" => $post->ID,
					"article_title" => $post->post_title,
					"article_categories" => $this->Routee_GetPostCategories($post->ID),
					"article_URL" => get_permalink($post),
			    );
			}
		}
		return $data;
	}

    /**
     * @param $postId
     * @return array
     */
	private function Routee_GetPostCategories( $postId ) {
		$cat_titles = array();
		$categories = wp_get_post_categories($postId);
		if (!empty($categories)) {
			foreach ( $categories as $category ) {
				$cat_titles[] = get_cat_name( $category );
			}
		}
		return $cat_titles;
	}


	/**
	 * @param $product
	 *
	 * @return void
	 */
	public function Routee_woocommerce_no_stock( $product ) {
        RouteeEventExecutedLog('ProductOutOfStock', 'events');

		$post_data = RouteeProductArray($product);
		$pro_data = $product->get_data();

		if($post_data['stock_quantity'] <= 0){
			if($pro_data['parent_id']!=0)
			{
				$data['product_id'] = $pro_data['parent_id'];
			}
			else
			{
				$data['product_id'] = $pro_data['id'];
			}

            RouteeEventGrabData('ProductOutOfStock', $data, 'events');
			Routee_http_call( self::EVENT_MODE, $data, 'ProductOutOfStock' );
		}
	}

	/**
	 * @param $product_id_with_stock
	 *
	 * @return void
	 */
	public function Routee_woocommerce_updated_product_stock( $product_id_with_stock ) {
        RouteeEventExecutedLog('ProductStockUpdate', 'events');

		$WC_Product = wc_get_product( $product_id_with_stock );
		$post_data = RouteeProductArray($WC_Product);
		$variation_id = 0;//Stock update for product not for variation so should be 0
		$data['product_id'] = $product_id_with_stock;
		$data['variation_id'] = $variation_id;
		$data['stock_quantity'] = $post_data['stock_quantity'];

        RouteeEventGrabData('ProductStockUpdate', $data, 'events');

        Routee_http_call( self::EVENT_MODE, $data, 'ProductStockUpdate' );
	}

	/**
	 * @param $token
	 *
	 * @return void
	 */
	public function Routee_woocommerce_add_to_cart($token) {
        RouteeEventExecutedLog('CartUpdate', 'events');

		global $woocommerce;
		$items = $woocommerce->cart->get_cart();

		$cart_pro = array();
		foreach ($items as $key => $item) {
			$cart_pro[] = array(
				'product_id' => $item['product_id'],
				'variation_id' => $item['variation_id'],
				'quantity' => $item['quantity']
			);
		}
		$post_data = array(
			'customer_id' => get_current_user_id(),
			'cart_products' => $cart_pro,
		);

        RouteeEventGrabData('CartUpdate', $post_data, 'events');
		Routee_http_call( self::EVENT_MODE, $post_data, 'CartUpdate', $token );
	}

	/**
	 * @param $cart_item_key
	 * @param $cart
	 *
	 * @return void
	 */
	public function Routee_remove_cart_items( $cart_item_key, $cart ) {
        RouteeEventExecutedLog('CartUpdate', 'events');

		$cart_pro = array();
		unset($cart->cart_contents[$cart_item_key]);
		if(!empty($cart->cart_contents)){
			foreach ($cart->cart_contents as $key => $value) {
				$cart_pro[] = array(
					'product_id' => $value['product_id'],
					'variation_id' => $value['variation_id'],
					'quantity' => $value['quantity'],
				);
			}
		}

		$post_data = array(
			'customer_id' => get_current_user_id(),
			'cart_products' => $cart_pro,
		);

        RouteeEventGrabData('CartUpdate', $post_data, 'events');
		Routee_http_call( self::EVENT_MODE, $post_data, 'CartUpdate', $cart_item_key );
	}

	/**
	 * @param $order_id
	 *
	 * @return void
	 */
	public function Routee_woocommerce_checkout_order($order_id){
        RouteeEventExecutedLog('OrderAdd', 'events');

		$order = new WC_Order( $order_id );

		$pro_ary = array();
		foreach( $order->get_items() as $product ) {
            $p_id = $product['variation_id'] ? $product['variation_id'] : $product['product_id'];
            $p_obj = wc_get_product($p_id);
			$pro_ary[] =array(
				'product_id' => $product['product_id'],
				'variation_id' => $product['variation_id'],
				'quantity'  =>  $product['qty'],
                'price' => $p_obj->get_regular_price(),
                'discounted_price' => !empty($p_obj->get_sale_price()) ? $p_obj->get_sale_price() : 0
			);
		}

		$shipping_method_title = '';
		foreach( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ){
			$shipping_method_title     = $shipping_item_obj->get_method_title();
		}
		$order_data = $order->get_data();
		$user_details = RouteeUserDetails( $order_data );

		$post_data = array(
			'customer_id' =>  $order_data['customer_id'],
			'order_details' => array(
				'order_id' => $order_id,
				'order_status' => $order_data['status'],
				'shipping_method' => $shipping_method_title,
				'payment_method' => get_post_meta( $order_id, '_payment_method', true ),
				'total_price' => $order_data['total'],
				'lastname'=>  $user_details['customer']['lastname'],
				"firstname"=>  $user_details['customer']['firstname'],
				"email" => $user_details['customer']['email'],
				"phone" => $user_details['customer']['phone'],
				'addresses' => $user_details['addresses']
			),
			'order_products' => $pro_ary,
		);

        RouteeEventGrabData('OrderAdd', $post_data, 'events');
		Routee_http_call( self::EVENT_MODE, $post_data, 'OrderAdd', $order_id );
	}

	/**
	 * @param $order_id
	 *
	 * @return void
	 */
	public function Routee_order_update_callback($order_id){
        RouteeEventExecutedLog('OrderStatusUpdate', 'events');

		$order = wc_get_order( $order_id );
		$order_data = $order->get_data();
		$tracking_number = '';
		$shipping_method_title = '';
		foreach( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ){
			$shipping_method_title     = $shipping_item_obj->get_method_title();
		}
		$tracking_number = get_post_meta($order->get_order_number(), 'Tracking_ID', true);

		$post_data = array(
			'customer_id' =>  $order_data['customer_id'],
			'order_id' => $order_id,
			'order_status' => $order_data['status'],
			'shipping_method' => $shipping_method_title,
			'tracking_number' => $tracking_number
		);

        RouteeEventGrabData('OrderStatusUpdate', $post_data, 'events');
		Routee_http_call( self::EVENT_MODE, $post_data, 'OrderStatusUpdate', $order_id );
	}

	/**
	 * @param $order_id
	 *
	 * @return void
	 */
	public function Routee_woocommerce_order_status_completed( $order_id ){
        RouteeEventExecutedLog('OrderPaymentConfirmed', 'events');

		$order = wc_get_order( $order_id );

		$data['customer_id'] = $order->get_user_id();
		$data['order_id'] = $order_id;

        RouteeEventGrabData('OrderPaymentConfirmed', $data, 'events');
		Routee_http_call( self::EVENT_MODE, $data, 'OrderPaymentConfirmed', $order_id );
	}

    /**
     * @return void
     */
    public function routee_log_export_csv(){
        global $wpdb;
        $logs_table = $wpdb->prefix. "store_events_logs";
        $query = "SELECT * FROM $logs_table WHERE is_exported='0'";

        $records = $wpdb->get_results($query);
        echo json_encode(array('success'=> 'yes', 'data' => $records));
        exit;
    }

    /**
     * @return void
     */
    public function routee_log_api() {
        global $wpdb;
        global $wp;
        $logs_table = $wpdb->prefix. "store_events_logs";

        $data_cycle = $_POST['data_cycle'];
        $postArr = $ids = [];
        $return["reload"] = 0;

        $offset = $this->limit * $data_cycle;

        $query = "SELECT * FROM $logs_table WHERE is_exported='0' ORDER BY id ASC LIMIT 100 OFFSET " . $offset;
        $logs = $wpdb->get_results($query, OBJECT);

        $count = count($logs);
        if ( $count > 0 ) {
            foreach ($logs as $key => $log) {
                $ids[] = $log->id;
                $postArr[] =  array(
                    'siteUrl' => home_url($wp->request),
                    'uuid' => !empty(get_option('RouteeLoginCode')) ? get_option('RouteeLoginCode') : '',
                    'event_name' => 'masslogs',
                    'log_type' => 'failure',
                    'log_data' => $log->log_data,
                    'created_at' => gmdate('d.m.Y H:i:s'),
                    'platform' => "WooCommerce"
                );
            }

            $response = wp_remote_post(ROUTEE_ERR_LOG_URL.'?multi=1', array(
                    'method'      => 'POST',
                    'httpversion' => '1.0',
                    'blocking'    => true,
                    'headers'     => array(),
                    'body'        => json_encode($postArr)
                )
            );
            $code = wp_remote_retrieve_response_code( $response );
            if ( $code == 200 && $count < 100 ){
                $return["reload"] = 1;
            }
        } else {
            $return["reload"] = 1;
        }

        $this->Routee_update_logs($code, $ids);
        wp_send_json($return);
    }

    /**
     * @param $code
     * @param $ids
     * @return void
     */
    public function Routee_update_logs($code, $ids) {
        global $wpdb;
        $logs_table = $wpdb->prefix. "store_events_logs";
        if ($code == 200) {
            $qry = "UPDATE $logs_table SET is_exported=1 WHERE is_exported=0 AND id IN (".implode(',',$ids).")";
            $wpdb->query($wpdb->prepare($qry));
        }
    }

    /**
     * @return void
     */
    public function routee_remove_log() {
        global $wpdb;
        $logs_table = $wpdb->prefix. "store_events_logs";
        $wpdb->query($wpdb->prepare("DELETE FROM $logs_table WHERE datediff(now(), $logs_table.created_at) > 7"));
    }
}
