<?php
if ( ! defined( 'ABSPATH' ) ) exit;
 
/**
 * @param $mode
 * @param $payload
 * @param $event
 * @param $post_id
 * @return array|int[]
 */
function Routee_http_call( $mode, $payload, $event = '', $post_id = 0 ) {
	if ( get_option('RouteeAuthorized') != '1' && $mode != 'auth' ) {
		return array(
			'success' => 0,
		);
	}
	include_once "Routee_Http.php";
	$http = new Routee_Http();
	return $http->make_http_call( $mode, $payload, $event, $post_id );
}

/**
 * @param $order_id
 * @return array[]
 */
function RouteeOrderDetails( $order_id ) {
	$order                 = wc_get_order( $order_id );
	$order_data            = $order->get_data();
	$shipping_method_title = '';
	foreach ( $order->get_items( 'shipping' ) as $item_id => $shipping_item_obj ) {
		$shipping_method_title     = $shipping_item_obj->get_method_title();
		$order_item_name           = $shipping_item_obj->get_name();
		$order_item_type           = $shipping_item_obj->get_type();
		$shipping_method_id        = $shipping_item_obj->get_method_id(); // The method ID
		$shipping_method_total     = $shipping_item_obj->get_total();
		$shipping_method_total_tax = $shipping_item_obj->get_total_tax();
		$shipping_method_taxes     = $shipping_item_obj->get_taxes();
	}

	return array(
		'order_details' => array(
			'customer_id'     => $order_data['customer_id'],
			'order_id'        => $order_id,
			'order_status'    => $order_data['status'],
			'shipping_method' => $shipping_method_title,
			'payment_method'  => get_post_meta( $order_id, '_payment_method', true ),
			'total_price'     => $order_data['total'],
		)
	);
}

/**
 * @param $user_id
 * @return array
 */
function RouteeUserArray( $user_id ) {

	$user_info = get_user_meta( $user_id );
	$addresses = array();
	$billing_add = array(
		'country'  => ( ! empty( $user_info['billing_country'] ) ? $user_info['billing_country'][0] : '' ),
		'city'     => ( ! empty( $user_info['billing_city'] ) ? $user_info['billing_city'][0] : '' ),
		'address1' => ( ! empty( $user_info['billing_address_1'] ) ? $user_info['billing_address_1'][0] : '' ),
		'postcode' => ( ! empty( $user_info['billing_postcode'] ) ? $user_info['billing_postcode'][0] : '' ),
		'company'  => ( ! empty( $user_info['billing_company'] ) ? $user_info['billing_company'][0] : '' )
	);
	$addresses[] = $billing_add;

	if ( ! empty( $user_info['shipping_country'][0] ) ) {
		$shipping_add = array(
			'country'  => ( ! empty( $user_info['shipping_country'] ) ? $user_info['shipping_country'][0] : '' ),
			'city'     => ( ! empty( $user_info['shipping_city'] ) ? $user_info['shipping_city'][0] : '' ),
			'address1' => ( ! empty( $user_info['shipping_address_1'] ) ? $user_info['shipping_address_1'][0] : '' ),
			'postcode' => ( ! empty( $user_info['shipping_postcode'] ) ? $user_info['shipping_postcode'][0] : '' ),
			'company'  => ( ! empty( $user_info['shipping_company'] ) ? $user_info['shipping_company'][0] : '' )
		);
		$addresses[]  = $shipping_add;
	}

	$user    = get_userdata( $user_id );
	$email   = $user->user_email;
	$phone = '';
	if ( isset( $user_info['billing_phone'] ) && ! empty( $user_info['billing_phone'][0] ) ) {
		$phone = $user_info['billing_phone'][0];
	}

	return array(
		'customer'  => array(
			'id'        => $user_id,
			'lastname'  => ( ! empty( $user_info['last_name'] ) ? $user_info['last_name'][0] : '' ),
			"firstname" => ( ! empty( $user_info['first_name'] ) ? $user_info['first_name'][0] : '' ),
			"birthday"  => "00/00/0000",
			"email"     => $email,
			"phone"     => RouteePhoneNumber( $phone )
		),
		'addresses' => $addresses
	);
}

/**
 * @param $order_data
 * @return array
 */
function RouteeUserDetails( $order_data ) {
	$user_id = $order_data['customer_id'];
	if ( $user_id ) {
		$return = RouteeUserArray( $user_id );
	} else {
		$billing_data = $order_data['billing'];
		$shipping_data = $order_data['shipping'];

		$firstname = $billing_data['first_name'];
		$lastname = $billing_data['last_name'];
		$email = $billing_data['email'];
		$phone = $billing_data['phone'];

		$billing_add = array(
			'country' => $billing_data['country'],
			'city' => $billing_data['city'],
			'address1' => $billing_data['address_1'],
			'postcode' => $billing_data['postcode'],
			'company' => $billing_data['company']
		);
		$addresses[] = $billing_add;

		$shipping_add = array(
			'country' => $shipping_data['country'],
			'city' => $shipping_data['city'],
			'address1' => $shipping_data['address_1'],
			'postcode' => $shipping_data['postcode'],
			'company' => $shipping_data['company']
		);
		$addresses[] = $shipping_add;
		$return = array(
			'customer'  => array(
				'id'        => $user_id,
				'lastname'  => $lastname,
				"firstname" => $firstname,
				"birthday"  => "00/00/0000",
				"email"     => $email,
				"phone"     => RouteePhoneNumber( $phone )
			),
			'addresses' => $addresses
		);
	}
	return $return;

}

/**
 * @param $product
 * @return array
 */
function RouteeProductArray($product) {
	$pro_data = $product->get_data();
	$variation = array();
	if($product->is_type( 'variable' )){
		$children = $product->get_available_variations();
		foreach ($children as $key=>$value) {

			if ( $value['variation_is_active'] == '1') {
				$v = array();
				$attributes = array_values($value['attributes']);
				$v['variation_id'] = $value['variation_id'];
				$v['variation'] = implode(',', $attributes);
				$v['price'] = $value['display_regular_price'];
				$v['stock_status'] = ($value['is_in_stock'] == '1' ? 'In stock' : '');
				$v['discount'] = array(
					'price' => $value['display_price'],
					"date_start" => "",
					"date_end"=> "",
					"quantity"=> null,
				);
				$variation[] = $v;
			}
		}
	}

	$terms = get_the_terms ( $pro_data['id'], 'product_cat' );

	$cats = array();
	if(!empty($terms)){
		foreach ( $terms as $term ) {
			$cats[] = $term->name;
		}
	}
	$discount = array();
	if($pro_data['sale_price'] != ''){
		$discount = array(
			'price'=> $pro_data['sale_price'],
			'date_start'=> ($pro_data['date_on_sale_from'] != '' ? $pro_data['date_on_sale_from']->date('d-m-Y H:i:s') : ''),
			'date_end'=> ($pro_data['date_on_sale_to'] != '' ? $pro_data['date_on_sale_to']->date('d-m-Y H:i:s') : ''),
			'quantity'=> null
		);
	}

	return array(
		'product_id' => $pro_data['id'],
		'name' => $pro_data['name'],
		'product_link' => get_permalink( $pro_data['id']),
		'price' => $pro_data['regular_price'],
		'stock_quantity' => $pro_data['stock_quantity'],
		'discount' => $discount,
		'categories' => $cats,
		'short_description' => $pro_data['short_description'],
		'description' => $pro_data['description'],
		"product_variations" => $variation,
		'image_link'=> get_the_post_thumbnail_url( $pro_data['id'], 'full' )
	);
}

/**
 * @param $phone_number
 * @return array|string|string[]|null
 */
function RouteePhoneNumber( $phone_number ) {

	$has_plus = strpos( $phone_number, '+' ) === 0 ? 1 : 0;
	$phone_number = preg_replace("/[^0-9]/", "", $phone_number);
	if ( strpos( $phone_number, '00' ) === 0 ) {
		str_replace( '00', '+', $phone_number );
	}
	if ($has_plus){
		$phone_number = '+'.$phone_number;
	}
	return $phone_number;
}

/**
 * @return bool
 */
function RouteeSyncCompleted(){
	$array = array(
		"product",
		"customer",
		"order"
	);
	foreach ( $array as $item ) {
		$data = "Routee".$item."Synced";
		if (get_option($data) != '1'){
			return false;
		}
	}
	return true;
}

/**
 * @param $data
 * @return bool
 */
function RouteeIfSynced($data){
	$data = "Routee".$data."Synced";
	return get_option($data) == '1';
}

/**
 * @param $text
 * @param $limit
 * @return mixed|string
 */
function RouteeLimitText($text, $limit) {
	if (str_word_count($text, 0) > $limit) {
		$words = str_word_count($text, 2);
		$pos   = array_keys($words);
		$text  = substr($text, 0, $pos[$limit]) . '...';
	}
	return $text;
}

/**
 * @param $mode
 * @param $code
 * @param $logdata
 * @return void
 */
function RouteeWriteLogs($mode, $code, $logdata) {
	include_once "Routee_Logs.php";
	new Routee_Logs($mode, $code, $logdata);
}

/**
 * @param $func
 * @param $method
 * @return void
 */
function RouteeEventExecutedLog($func, $method) {
    $payload = array(
        'function' => $func,
        'method' => $method,
        'desc' => 'Hook function executed.'
    );
    RouteeWriteLogs($method, 200, $payload);
}

/**
 * @param $func
 * @param $data
 * @param $method
 * @return void
 */
function RouteeEventGrabData($func, $data, $method) {
    $payload = array(
        'function' => $func,
        'method' => $method,
        'postdata' => $data,
        'desc' => 'Event data grabbed.'
    );
    RouteeWriteLogs($method, 200, $payload);
}

/**
 * @param $func
 * @param $data
 * @param $method
 * @return void
 */
function RouteeEventPayloadData($func, $data, $method) {
    $payload = array(
        'function' => $func,
        'method' => $method,
        'api_payload' => $data,
        'desc' => 'Event API payload is prepared.'
    );
    RouteeWriteLogs($method, 200, $payload);
}

/**
 * @return array|object|stdClass[]|null
 */
function RouteeGetLatestPosts() {
	global $wpdb;
	$querystr = "
			    SELECT $wpdb->posts.ID
			    FROM $wpdb->posts
			    WHERE $wpdb->posts.post_status = 'publish' 
			    AND $wpdb->posts.post_type = 'post'
			    ORDER BY $wpdb->posts.post_date DESC
				LIMIT 19 OFFSET 1";

	return $wpdb->get_results($querystr, OBJECT);
}
