<?php
if (!defined('ABSPATH'))
    exit;
$wp_nonce = wp_create_nonce('ajax-nonce');
?>

<div class="wrap">
    <h2 class="main-heading">Welcome to Routee</h2>
    <b style="color: green">
    <?php
            echo RouteeSyncCompleted() ? "Data synchronization completed" : "Congratulations you are successfully authorized. Start data synchronization";
    ?>
    </b>
    <table class="form-table">
        <tbody>
            <tr>
                <th class="label">Products Synchronization </th>
                <td><button class="button button-primary mass-data" data-action="product" <?= RouteeIfSynced("Product") ? "disabled" : "" ?>>Start Syncing</button></td>
            </tr>
            <tr>
                <th class="label">Customers Synchronization </th>
                <td><button class="button button-primary mass-data" data-action="customer" <?= RouteeIfSynced("Customer") ? "disabled" : "" ?>>Start Syncing</button></td>
            </tr>
            <tr>
                <th class="label">Orders Synchronization </th>
                <td><button class="button button-primary mass-data" data-action="order" <?= RouteeIfSynced("Order") ? "disabled" : "" ?>>Start Syncing</button></td>
            </tr>

            <tr>
                <th class="label">Export Routee Logs </th>
                <td>
                    <button class="button button-primary" data-action="routee_log_export_csv" id="routee-log-export-btn">
                        Export Logs
                    </button>
                </td>
            </tr>

            <tr>
                <th class="label">Export Logs API </th>
                <td>
                    <button class="button button-primary" data-action="routee_log_api" id="routee-log-export-api">
                        Export Logs API
                    </button>
                </td>
            </tr>

        </tbody>
    </table>
</div>

<script>
    jQuery(document).ready(function($){
        let data_cycle = 0;
        let action = "";
        //Mass Export Button click
        $(".mass-data").click(function (event) {
            $(".mass-data").attr("disabled", "true");
            action = $(this).attr("data-action");
            let data = {'action':'routee_mass_data','data_type':action, 'data_cycle': data_cycle, _ajax_nonce: '<?= $wp_nonce; ?>'};
            make_ajax(data);
        })

        //Download Log CSV file
        $("#routee-log-export-btn").click(function (event) {
            $(this).attr("disabled", "true");
            action = $(this).attr("data-action");
            let data = {'action' :action, _ajax_nonce: '<?= $wp_nonce; ?>'};
            make_ajax(data, 'logs');
        })

        //Export logs to api
        $("#routee-log-export-api").click(function (event) {
            $(this).attr("disabled", "true");
            action = $(this).attr("data-action");
            let data = {'action' :action, 'data_cycle': data_cycle, _ajax_nonce: '<?= $wp_nonce; ?>'};
            make_ajax(data, 'logsapi');
        })

        /**
         *
         * @param data
         * @param type
         */
        function make_ajax(data, type = 'mass') {
            $.ajax({
                type: "POST",
                url: "<?php echo admin_url('admin-ajax.php'); ?>",
                data: data,
                dataType: 'json',
            }).fail(function (jqXHR, textStatus, errorThrown) {
                console.log('error ' + textStatus);
            }).done(function (data, textStatus, jqXHR) {
                if(type == 'mass') {
                    process_result(data, 'routee_mass_data')
                }

                if(type == 'logs') {
                    generate_csv(data)
                }

                if(type == 'logsapi') {
                    process_result(data, 'routee_log_api')
                }
            });
        }

        /**
         *
         * @param data
         * @param actionName
         */
        function process_result(data, actionName) {
            data_cycle++;
            if (data.reload === 1){
                location.reload();
            } else if (data.reload === 0){
                let req = {'action':actionName,'data_type':action, 'data_cycle': data_cycle, _ajax_nonce: '<?= $wp_nonce; ?>'};
                make_ajax(req);
            }
        }

        /**
         *
         * @param success
         */
        function generate_csv(success) {
            if (success.success == "yes") {
                var rec_arr = success.data;

                let csv_arr = [];
                let csv_header_arr = [
                    "ID",
                    "Log Type",
                    "Event Type",
                    "Log Date",
                    "Is Exported",
                    "Created at"
                ];
                csv_arr.push(csv_header_arr);
                let record_arr = [];

                for (i = 0; i < rec_arr.length; i++) {

                    record_arr.push(rec_arr[i].id);
                    record_arr.push(rec_arr[i].log_type);
                    record_arr.push(rec_arr[i].event_type);
                    record_arr.push(rec_arr[i].log_data);
                    record_arr.push(rec_arr[i].is_exported);
                    record_arr.push(rec_arr[i].created_at);
                    csv_arr.push(record_arr);
                    record_arr = [];
                }

                var csv_content = arrayToCsv(csv_arr);
                var timeElapsed = Date.now();
                var today = new Date(timeElapsed);
                var year = today.getFullYear();
                var month = today.getMonth() + 1;
                var day = today.getDate();
                var filename = "Routee_Log_" + year + month + day + ".csv";
                downloadBlob(csv_content, filename, "text/csv;charset=utf-8;");
            }
        }

        /**
         *
         * @param content
         * @param filename
         * @param contentType
         */
        function downloadBlob(content, filename, contentType) {
            // Create a blob
            var blob = new Blob([content], { type: contentType });
            var url = URL.createObjectURL(blob);

            // Create a link to download it
            var pom = document.createElement("a");
            pom.href = url;
            pom.setAttribute("download", filename);
            pom.click();
            pom.remove();
        }

        /**
         *
         * @param data
         * @returns {*}
         */
        function arrayToCsv(data) {
            return data
                .map(
                    (row) =>
                        row
                            .map(String) // convert every value to String
                            .map((v) => v.replaceAll('"', '""')) // escape double colons
                            .map((v) => `"${v}"`) // quote it
                            .join(",") // comma-separated
                )
                .join("\r\n"); // rows starting on new lines
        }
    })
</script>
